@@ -4,7 +4,6 @@
 import os.path
 import sys
 import numpy as np
-import json
 
 # third-party imports
 import cyvcf as vcf
@@ -14,7 +13,7 @@ import version
 from ped import load_ped_file
 import gene_table
 import infotag
-from database_cassandra import insert, batch_insert, batch_insert_query_prepared, create_tables
+from database_cassandra import insert, batch_insert, create_tables
 import annotations
 import func_impact
 import severe_impact
@@ -33,6 +32,11 @@ from random import randint
 from geminicassandra.table_schemes import get_column_names
 from cassandra.query import BatchStatement, BatchType
 import Queue
+from cassandra.concurrent import execute_concurrent_with_args
+import cassandra
+from multiprocessing import cpu_count
+from time import sleep
+from sys import stderr
 
 class GeminiLoader(object):
     """
@@ -58,6 +62,7 @@ class GeminiLoader(object):
         if not self.args.no_genotypes:
             self.samples = self.vcf_reader.samples
             self.gt_column_names, self.typed_gt_column_names = self._get_typed_gt_column_names()
+            print "# samples = %s" % len(self.samples)
             
         NUM_BUILT_IN = 6
         self.extra_sample_columns = get_ped_fields(args.ped_file)[NUM_BUILT_IN:]        
@@ -75,10 +80,7 @@ class GeminiLoader(object):
         if not self.args.no_genotypes and not self.args.no_load_genotypes:
                 # load the sample info from the VCF file.
             self._prepare_samples()
-                # initialize genotype counts for each sample
-            self.num_samples = len(self.samples)
-        else:
-            self.num_samples = 0
+                # initialize genotype counts for each sampl  
             
         if not self.args.skip_gene_tables:
             self._get_gene_detailed()
@@ -126,10 +128,10 @@ class GeminiLoader(object):
         
         basic_query = 'INSERT INTO %s ( %s ) VALUES ( %s  )'
         
-        from time import sleep
-        
-        nap = 20*randint(0,6)
-        sleep(nap)
+        if cpu_count() > 8:
+            
+            nap = 20*randint(0,6)
+            sleep(nap)
         
         start_time = time.time()
         
@@ -154,7 +156,7 @@ class GeminiLoader(object):
                        
         end_time = time.time()
         
-        print("preparing statements took %.2f s." % (end_time - start_time))
+        print "Proc %s: preparing statements took %.2f s." % (os.getpid(), (end_time - start_time))
                                                  
     def populate_from_vcf(self):
         """
@@ -166,6 +168,9 @@ class GeminiLoader(object):
         self.var_gene_buffer = blist([])
         self.var_chrom_start_buffer = blist([])
         self.prepare_insert_queries()
+        self.leftover_types = blist([])
+        self.leftover_depths = blist([])
+        self.leftover_gts = blist([])
         buffer_count = 0
         self.skipped = 0
         #extra_file, extraheader_file = geminicassandra.get_extra_files(self.args.db)
@@ -174,7 +179,8 @@ class GeminiLoader(object):
         start_time = time.time()
         interval_start = time.time()
         variants_gts_timer = 0
-        log_file = open("loading_logs/%s.csv" % str(os.getpid()), "a")
+        log_file = open("loading_logs/%s.csv" % str(os.getpid()), "w")
+        self.time_out_log = open("loading_logs/%s.err" % str(os.getpid()), "w")
         #with open(extra_file, "w") as extra_handle:
             # process and load each variant in the VCF file
         vars_inserted = 0
@@ -188,7 +194,7 @@ class GeminiLoader(object):
             self.var_subtypes_buffer.append([self.v_id, variant[11], variant[12]])
             if variant[55] != None:
                 self.var_gene_buffer.append([self.v_id, variant[55]])
-            self.var_chrom_start_buffer.append([self.v_id, variant[0], variant[1]])
+            self.var_chrom_start_buffer.append([self.v_id, variant[1], variant[2]])
         
             var_sample_gt_types_buffer = blist([])
             var_sample_gt_depths_buffer = blist([])
@@ -201,7 +207,7 @@ class GeminiLoader(object):
                     var_sample_gt_buffer.append([self.v_id, sample[0], sample[3]])        
                              
             stime = time.time()                       
-            self.prepared_batch_insert(self.session, var_sample_gt_types_buffer, var_sample_gt_depths_buffer, var_sample_gt_buffer)
+            self.prepared_batch_insert(var_sample_gt_types_buffer, var_sample_gt_depths_buffer, var_sample_gt_buffer, 25)
             variants_gts_timer += (time.time() - stime)
             
                 # add each of the impact for this variant (1 per gene/transcript)
@@ -212,11 +218,11 @@ class GeminiLoader(object):
                 # buffer full - start to insert into DB
             if buffer_count >= self.buffer_size:
                 startt = time.time()
-                batch_insert_query_prepared(self.session, self.insert_variants_query, self.var_buffer,self.queue_length)
-                batch_insert_query_prepared(self.session, self.insert_variant_impacts_query, self.var_impacts_buffer,self.queue_length)
-                batch_insert_query_prepared(self.session, self.insert_variant_stcr_query, self.var_subtypes_buffer,self.queue_length)
-                batch_insert_query_prepared(self.session, self.insert_variant_gene_query, self.var_gene_buffer,self.queue_length)
-                batch_insert_query_prepared(self.session, self.insert_variant_chrom_start_query, self.var_chrom_start_buffer,self.queue_length)
+                self.execute_concurrent_with_retry(self.insert_variants_query, self.var_buffer)
+                self.execute_concurrent_with_retry(self.insert_variant_impacts_query, self.var_impacts_buffer)
+                self.execute_concurrent_with_retry(self.insert_variant_stcr_query, self.var_subtypes_buffer)
+                self.execute_concurrent_with_retry(self.insert_variant_gene_query, self.var_gene_buffer)
+                self.execute_concurrent_with_retry(self.insert_variant_chrom_start_query, self.var_chrom_start_buffer)
                 endt = time.time()
                     # binary.genotypes.append(var_buffer)
                     # reset for the next batch
@@ -226,8 +232,6 @@ class GeminiLoader(object):
                 self.var_gene_buffer = blist([])
                 self.var_chrom_start_buffer = blist([])
                 vars_inserted += self.buffer_size   
-                if(self.args.offset == '1'):                   
-                    print "%s vars done; last %s took %.2f s; var tables %.2f s; var_gt_tables %.2f s" % (vars_inserted, self.buffer_size, endt - interval_start, endt - startt, variants_gts_timer) 
                 log_file.write("%s;%.2f;%.2f;%.2f\n" % (self.buffer_size, endt - interval_start, endt - startt, variants_gts_timer)) 
                 log_file.flush()       
                 buffer_count = 0
@@ -244,42 +248,113 @@ class GeminiLoader(object):
         self.v_id -= 1
         
         startt = time.time()
-        batch_insert_query_prepared(self.session, self.insert_variants_query, self.var_buffer,self.queue_length)
-        batch_insert_query_prepared(self.session, self.insert_variant_impacts_query, self.var_impacts_buffer,self.queue_length)
-        batch_insert_query_prepared(self.session, self.insert_variant_stcr_query, self.var_subtypes_buffer,self.queue_length)
-        batch_insert_query_prepared(self.session, self.insert_variant_gene_query, self.var_gene_buffer,self.queue_length)
-        batch_insert_query_prepared(self.session, self.insert_variant_chrom_start_query, self.var_chrom_start_buffer,self.queue_length)
+        self.execute_concurrent_with_retry(self.insert_variants_query, self.var_buffer)
+        self.execute_concurrent_with_retry(self.insert_variant_impacts_query, self.var_impacts_buffer)
+        self.execute_concurrent_with_retry(self.insert_variant_stcr_query, self.var_subtypes_buffer)
+        self.execute_concurrent_with_retry(self.insert_variant_gene_query, self.var_gene_buffer)
+        self.execute_concurrent_with_retry(self.insert_variant_chrom_start_query, self.var_chrom_start_buffer)
+        
+        #self.prepared_batch_insert(self.leftover_types, self.leftover_depths, self.leftover_gts)
         
         end_time = time.time()
         vars_inserted += self.buffer_size   
-        log_file.write("%s;%.2f;%.2f;%.2f\n" % (self.buffer_size, end_time - interval_start, end_time - startt, variants_gts_timer))        
-        log_file.close()        
+        log_file.write("%d;%.2f;%.2f;%.2f\n" % (len(self.var_buffer), end_time - interval_start, end_time - startt, variants_gts_timer))        
+        
+        self.time_out_log.close()   
         elapsed_time = end_time - start_time            
         sys.stderr.write("pid " + str(os.getpid()) + ": " +
                          str(self.counter) + " variants processed in %s s.\n" % elapsed_time)
+        log_file.write(str(self.counter) + " variants processed in %s s.\n" % elapsed_time)
+        log_file.write("%d leftovers\n" % len(self.leftover_types))
+        log_file.close()     
         if self.args.passonly:
             sys.stderr.write("pid " + str(os.getpid()) + ": " +
                              str(self.skipped) + " skipped due to having the "
                              "FILTER field set.\n")
             
-    def prepared_batch_insert(self, session, types_buf, depth_buf, gt_buffer, queue_length=120):
+    def prepared_batch_insert(self, types_buf, depth_buf, gt_buffer, queue_length=40):
         """
         Populate the given table with the given values
         """
-        
+        retry_threshold = 8
         futures = Queue.Queue(maxsize=queue_length+1)
-        for i in range(len(types_buf)):
+        retries = {}
+        i = 0
+        while i < len(types_buf):
             if i >= queue_length:
-                old_future = futures.get_nowait()
-                old_future.result()
+                (old_i, old_future) = futures.get_nowait()
+                try:
+                    old_future.result()
+                    del retries[old_i]
+                except cassandra.WriteTimeout:
+                    if retries[old_i] < retry_threshold:
+                        if retries[old_i] == 0:
+                            self.write_to_timeoutlog("1::%s;%s;%s\n" % \
+                                                    (types_buf[old_i][0], types_buf[old_i][1], types_buf[old_i][2]))
+                        future = self.execute_var_gts_batch(types_buf[old_i], depth_buf[old_i], gt_buffer[old_i])      
+                        futures.put_nowait((old_i, future))
+                        retries[old_i] += 1
+                        continue
+                    else:
+                        self.leftover_types.append(types_buf[old_i])
+                        self.leftover_depths.append(depth_buf[old_i])
+                        self.leftover_gts.append(gt_buffer[old_i])
+                        self.write_to_timeoutlog("2::%s;%s;%s;%s;%s\n" % \
+                                                (types_buf[old_i][0], types_buf[old_i][1], types_buf[old_i][2], depth_buf[old_i][2], gt_buffer[old_i][2]))
+                        
+                except cassandra.InvalidRequest:
+                    if retries[old_i] < retry_threshold:
+                        if retries[old_i] == 0:
+                            self.write_to_timeoutlog("3::%s;%s;%s\n" % \
+                                                    (types_buf[old_i][0], types_buf[old_i][1], types_buf[old_i][2]))
+                        future = self.execute_var_gts_batch(types_buf[old_i], depth_buf[old_i], gt_buffer[old_i])      
+                        futures.put_nowait((old_i, future))
+                        retries[old_i] += 1
+                        continue
+                    else:
+                        self.leftover_types.append(types_buf[old_i])
+                        self.leftover_depths.append(depth_buf[old_i])
+                        self.leftover_gts.append(gt_buffer[old_i])
+                        self.write_to_timeoutlog("4::%s;%s;%s;%s;%s\n" % \
+                                                (types_buf[old_i][0], types_buf[old_i][1], types_buf[old_i][2], depth_buf[old_i][2], gt_buffer[old_i][2]))
+                        
+                except cassandra.OperationTimedOut as e:
+                    self.write_to_timeoutlog(str(e))
+                    stderr.write("Proc %s: OperationTimedOut - goodbye\n")
+                    sys.exit()
+                
+            future = self.execute_var_gts_batch(types_buf[i], depth_buf[i], gt_buffer[i])
+            futures.put_nowait((i, future))
+            retries[i] = 0
+            i += 1   
             
-            batch = BatchStatement(batch_type=BatchType.UNLOGGED)
-            batch.add(self.insert_samples_variants_gt_types_query, types_buf[i])
-            batch.add(self.insert_variants_samples_gt_types_query, types_buf[i])
-            batch.add(self.insert_variants_samples_gt_depths_query, depth_buf[i])
-            batch.add(self.insert_variants_samples_gts_query, gt_buffer[i])
-            future = session.execute_async(batch)
-            futures.put_nowait(future)
+    def execute_var_gts_batch(self, type_info, depth, gt):
+        batch = BatchStatement(batch_type=BatchType.UNLOGGED)
+        batch.add(self.insert_samples_variants_gt_types_query, type_info)
+        batch.add(self.insert_variants_samples_gt_types_query, type_info)
+        batch.add(self.insert_variants_samples_gt_depths_query, depth)
+        batch.add(self.insert_variants_samples_gts_query, gt)
+        return self.session.execute_async(batch)
+            
+    def execute_concurrent_with_retry(self, insert_query, contents, retry=0):
+        try:
+            execute_concurrent_with_args(self.session, insert_query, contents)
+        except cassandra.WriteTimeout:
+            self.write_to_timeoutlog("5::%d\n" % contents[0][0])   
+            self.execute_concurrent_with_retry(insert_query, contents, retry)
+        except cassandra.InvalidRequest as e:
+            if retry < 8:
+                self.write_to_timeoutlog("6::%d\n" % contents[0][0])   
+                self.execute_concurrent_with_retry(insert_query, contents, retry+1)
+            else:
+                self.write_to_timeoutlog("Give up - too many invalid dink\n")
+                self.write_to_timeoutlog(str(e))
+                raise e
+            
+    def write_to_timeoutlog(self, message):
+        self.time_out_log.write(message)
+        self.time_out_log.flush()
+                   
 
     def _update_extra_headers(self, headers, cur_fields):
         """Update header information for extra fields.
@@ -592,8 +667,8 @@ class GeminiLoader(object):
         if extra_fields:
             extra_fields.update({"chrom": var.CHROM, "start": var.start, "end": var.end})
         chrom = var.CHROM if var.CHROM.startswith("chr") else "chr" + var.CHROM
-        variant = [chrom, var.start, var.end,
-                   vcf_id, self.v_id, anno_id, var.REF, ','.join(var.ALT),
+        variant = [self.v_id, chrom, var.start, var.end,
+                   vcf_id, anno_id, var.REF, ','.join(var.ALT),
                    var.QUAL, var_filter, var.var_type,
                    var.var_subtype,
                    call_rate, in_dbsnp,
