@@ -136,6 +136,29 @@ def main():
                          action='store_true',
                          help='Load in test mode (faster)',
                          default=False)
+    parser_load.add_argument('--timing-log',
+                             dest = "timing_log",
+                             default = None,
+                             help = "File to log time taken for loading")
+    parser_load.add_argument('--exp-id',
+                             dest = "exp_id",
+                             default = "",
+                             help = "Identifier for the test run")
+    parser_load.add_argument('--buffer-size',
+                             dest = "buffer_size",
+                             default = 333,
+                             type=int,
+                             help = "buffer size when loading")
+    parser_load.add_argument('--replication',
+                             dest= "replication",
+                             default = 1,
+                             type=int,
+                             help="replication factor for the Cassandra cluster")
+    parser_load.add_argument('--max_queue',
+                             dest= "max_queue",
+                             default = 120,
+                             type=int,
+                             help="queue length (per core) for batched inserts to Cassandra")
 
     def load_fn(parser, args):
         import gemini_load
@@ -232,6 +255,22 @@ def main():
                          action='store_true',
                          help='Load in test mode (faster)',
                          default=False)
+    parser_loadchunk.add_argument('--buffer-size',
+                             dest = "buffer_size",
+                             default = 333,
+                             type=int,
+                             help = "buffer size when loading")
+    parser_loadchunk.add_argument('--replication',
+                             dest= "replication",
+                             default = 1,
+                             type=int,
+                             help="replication factor for the Cassandra cluster")
+    parser_loadchunk.add_argument('--max_queue',
+                             dest= "max_queue",
+                             default = 120,
+                             type=int,
+                             help="queue length (per core) for batched inserts to Cassandra")
+    
     def loadchunk_fn(parser, args):
         import gemini_load_chunk
         gemini_load_chunk.load(parser, args)
